==> v2.3.4.tar.gz: privacyguides.org/docs/self-contained-networks.en.md <==
---
title: "Self-Contained Networks"
icon: material/security-network
---
If you are currently browsing clearnet and want to access the dark web, this section is for you.

## Self-contained Networks

### Tor

!!! recommendation

    ![Tor logo](assets/img/self-contained-networks/tor.svg){ align=right }

    The Tor network is a group of volunteer-operated servers that allows people to improve their privacy and security on the Internet. Tor's users employ this network by connecting through a series of virtual tunnels rather than making a direct connection, thus allowing both organizations and individuals to share information over public networks without compromising their privacy. Tor is an effective censorship circumvention tool.

    [Visit torproject.org](https://www.torproject.org){ .md-button .md-button--primary } [:pg-tor:](http://2gzyxa5ihm7nsggfxnu52rck2vv4rvmdlkiu3zzui5du4xyclen53wid.onion){ .md-button }

    **Downloads**
    - [:fontawesome-brands-windows: Windows](https://www.torproject.org/download/)
    - [:fontawesome-brands-apple: macOS](https://www.torproject.org/download/)
    - [:fontawesome-brands-linux: Linux](https://www.torproject.org/download/)
    - [:fontawesome-brands-freebsd: FreeBSD](https://www.freshports.org/security/tor)
    - [:pg-openbsd: OpenBSD](https://openports.se/net/tor)
    - [:pg-netbsd: NetBSD](https://pkgsrc.se/net/tor)
    - [:fontawesome-brands-google-play: Google Play](https://play.google.com/store/apps/details?id=org.torproject.torbrowser)
    - [:pg-f-droid: F-Droid](https://support.torproject.org/tormobile/tormobile-7/)
    - [:fontawesome-brands-android: Android](https://www.torproject.org/download/#android)
    - [:fontawesome-brands-git: Source](https://gitweb.torproject.org/tor.git)

### I2P Anonymous Network

!!! recommendation

    ![I2P logo](assets/img/self-contained-networks/i2p.svg#only-light){ align=right }
    ![I2P logo](assets/img/self-contained-networks/i2p-dark.svg#only-dark){ align=right }

    The Invisible Internet Project (I2P) is a computer network layer that allows applications to send messages to each other pseudonymously and securely. Uses include anonymous Web surfing, chatting, blogging, and file transfers. The software that implements this layer is called an I2P router and a computer running I2P is called an I2P node. The software is free and open-source and is published under multiple licenses.

    [Visit geti2p.net](https://geti2p.net){ .md-button .md-button--primary } [:pg-i2p:](http://i2p-projekt.i2p){ .md-button }

    **Downloads**
    - [:fontawesome-brands-windows: Windows](https://geti2p.net/en/download#windows)
    - [:fontawesome-brands-apple: macOS](https://geti2p.net/en/download#mac)
    - [:fontawesome-brands-linux: Linux](https://geti2p.net/en/download#unix)
    - [:fontawesome-brands-freebsd: FreeBSD](https://www.freshports.org/security/i2p)
    - [:pg-openbsd: OpenBSD](https://openports.se/net/i2pd)
    - [:pg-netbsd: NetBSD](https://pkgsrc.se/wip/i2pd)
    - [:fontawesome-brands-google-play: Google Play](https://play.google.com/store/apps/details?id=net.i2p.android)
    - [:pg-f-droid: F-Droid](https://f-droid.org/app/net.i2p.android.router)
    - [:fontawesome-brands-android: Android](https://download.i2p2.de/android/current/)
    - [:fontawesome-brands-git: Source](https://geti2p.net/en/get-involved/guides/new-developers#getting-the-i2p-code)

### The Freenet Project

!!! recommendation

    ![Freenet logo](assets/img/self-contained-networks/freenet.svg){ align=right }

    Freenet is a peer-to-peer platform for censorship-resistant communication. It uses a decentralized distributed data store to keep and deliver information, and has a suite of free software for publishing and communicating on the Web without fear of censorship. Both Freenet and some of its associated tools were originally designed by Ian Clarke, who defined Freenet's goal as providing freedom of speech on the Internet with strong anonymity protection.

    [Visit freenetproject.org/](https://freenetproject.org){ .md-button .md-button--primary }

    **Downloads**
    - [:fontawesome-brands-windows: Windows](https://freenetproject.org/pages/download.html#windows)
    - [:fontawesome-brands-apple: macOS](https://freenetproject.org/pages/download.html#os-x)
    - [:fontawesome-brands-linux: Linux](https://freenetproject.org/pages/download.html#gnulinux-posix)
    - [:fontawesome-brands-freebsd: FreeBSD](https://freenetproject.org/pages/download.html#gnulinux-posix)
    - [:pg-openbsd: OpenBSD](https://freenetproject.org/pages/download.html#gnulinux-posix)
    - [:pg-netbsd: NetBSD](https://freenetproject.org/pages/download.html#gnulinux-posix)
    - [:fontawesome-brands-github: Source](https://github.com/freenet/)

==> v2.4.2.tar.gz: privacyguides.org/docs/self-contained-networks.en.md <==
---
title: "Self-Contained Networks"
icon: material/security-network
---
If you are currently browsing clearnet and want to access the dark web, this section is for you.

## Self-contained Networks

### Tor

!!! recommendation

    ![Tor logo](assets/img/self-contained-networks/tor.svg){ align=right }

    The **Tor** network is a group of volunteer-operated servers that allows people to improve their privacy and security on the Internet. Tor's users employ this network by connecting through a series of virtual tunnels rather than making a direct connection, thus allowing both organizations and individuals to share information over public networks without compromising their privacy. Tor is an effective censorship circumvention tool.

    [Visit torproject.org](https://www.torproject.org){ .md-button .md-button--primary } [:pg-tor:](http://2gzyxa5ihm7nsggfxnu52rck2vv4rvmdlkiu3zzui5du4xyclen53wid.onion){ .md-button }

    **Downloads**
    - [:fontawesome-brands-windows: Windows](https://www.torproject.org/download/)
    - [:fontawesome-brands-apple: macOS](https://www.torproject.org/download/)
    - [:fontawesome-brands-linux: Linux](https://www.torproject.org/download/)
    - [:fontawesome-brands-freebsd: FreeBSD](https://www.freshports.org/security/tor)
    - [:pg-openbsd: OpenBSD](https://openports.se/net/tor)
    - [:pg-netbsd: NetBSD](https://pkgsrc.se/net/tor)
    - [:fontawesome-brands-google-play: Google Play](https://play.google.com/store/apps/details?id=org.torproject.torbrowser)
    - [:pg-f-droid: F-Droid](https://support.torproject.org/tormobile/tormobile-7/)
    - [:fontawesome-brands-android: Android](https://www.torproject.org/download/#android)
    - [:fontawesome-brands-git: Source](https://gitweb.torproject.org/tor.git)

### Invisible Internet Project

!!! recommendation

    ![I2P logo](assets/img/self-contained-networks/i2p.svg#only-light){ align=right }
    ![I2P logo](assets/img/self-contained-networks/i2p-dark.svg#only-dark){ align=right }

    **I2P** is a computer network layer that allows applications to send messages to each other pseudonymously and securely. Uses include anonymous Web surfing, chatting, blogging, and file transfers. The software that implements this layer is called an I2P router and a computer running I2P is called an I2P node. The software is free and open-source and is published under multiple licenses.

    [Visit geti2p.net](https://geti2p.net){ .md-button .md-button--primary } [:pg-i2p:](http://i2p-projekt.i2p){ .md-button }

    **Downloads**
    - [:fontawesome-brands-windows: Windows](https://geti2p.net/en/download#windows)
    - [:fontawesome-brands-apple: macOS](https://geti2p.net/en/download#mac)
    - [:fontawesome-brands-linux: Linux](https://geti2p.net/en/download#unix)
    - [:fontawesome-brands-freebsd: FreeBSD](https://www.freshports.org/security/i2p)
    - [:pg-openbsd: OpenBSD](https://openports.se/net/i2pd)
    - [:pg-netbsd: NetBSD](https://pkgsrc.se/wip/i2pd)
    - [:fontawesome-brands-google-play: Google Play](https://play.google.com/store/apps/details?id=net.i2p.android)
    - [:pg-f-droid: F-Droid](https://f-droid.org/app/net.i2p.android.router)
    - [:fontawesome-brands-android: Android](https://download.i2p2.de/android/current/)
    - [:fontawesome-brands-git: Source](https://geti2p.net/en/get-involved/guides/new-developers#getting-the-i2p-code)

### The Freenet Project

!!! recommendation

    ![Freenet logo](assets/img/self-contained-networks/freenet.svg){ align=right }

    **Freenet** is a peer-to-peer platform for censorship-resistant communication. It uses a decentralized distributed data store to keep and deliver information, and has a suite of free software for publishing and communicating on the Web without fear of censorship. Both Freenet and some of its associated tools were originally designed by Ian Clarke, who defined Freenet's goal as providing freedom of speech on the Internet with strong anonymity protection.

    [Visit freenetproject.org/](https://freenetproject.org){ .md-button .md-button--primary }

    **Downloads**
    - [:fontawesome-brands-windows: Windows](https://freenetproject.org/pages/download.html#windows)
    - [:fontawesome-brands-apple: macOS](https://freenetproject.org/pages/download.html#os-x)
    - [:fontawesome-brands-linux: Linux](https://freenetproject.org/pages/download.html#gnulinux-posix)
    - [:fontawesome-brands-freebsd: FreeBSD](https://freenetproject.org/pages/download.html#gnulinux-posix)
    - [:pg-openbsd: OpenBSD](https://freenetproject.org/pages/download.html#gnulinux-posix)
    - [:pg-netbsd: NetBSD](https://freenetproject.org/pages/download.html#gnulinux-posix)
    - [:fontawesome-brands-github: Source](https://github.com/freenet/)

--8<-- "includes/abbreviations.en.md"
